@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_applicationautoscaling._jsii
 import aws_cdk.aws_cloudwatch._jsii
@@ -18,7 +18,7 @@ import aws_cdk.custom_resources._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/aws-dynamodb", "1.62.0", __name__[0:-6], "aws-dynamodb@1.62.0.jsii.tgz"
+    "@aws-cdk/aws-dynamodb", "1.64.0", __name__[0:-6], "aws-dynamodb@1.64.0.jsii.tgz"
 )
 
 __all__ = [
